Coverage for /home/tribaal/workspace/django-shop/shop/models/__init__: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/models/__init__ : 100.00%

## 7 statements 7 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | from django.conf import settings from cartmodel import * # NOQA from ordermodel import * # NOQA from productmodel import * # NOQA from shop.order_signals import * # NOQA from shop.util.loader import load_class # Load the class specified by the user as the Address Model. AddressModel = load_class(getattr(settings, 'SHOP_ADDRESS_MODEL', 'shop.addressmodel.models.Address'))